@@ -1,11 +1,11 @@
 package Dist::Zilla::PluginBundle::AMD;
-# git description: v0.008-3-gdf0ed50
+# git description: v0.009-1-g38de993
 
 BEGIN {
   $Dist::Zilla::PluginBundle::AMD::AUTHORITY = 'cpan:AMD';
 }
 {
-  $Dist::Zilla::PluginBundle::AMD::VERSION = '0.009';
+  $Dist::Zilla::PluginBundle::AMD::VERSION = '0.010';
 }
 # ABSTRACT: Build your distributions like AMD does
 
@@ -86,6 +86,12 @@ has disable_trailing_whitespace_tests => (
     default => 0,
 );
 
+has disable_tab_tests => (
+    is      => 'ro',
+    isa     => Bool,
+    default => 0,
+);
+
 has bugtracker_url => (
     isa     => Uri,
     coerce  => 1,
@@ -321,9 +327,11 @@ method configure {
         MetaJSON
         PkgVersion
         PodSyntaxTests
-        NoTabsTests
     ));
 
+    $self->add_plugins('NoTabsTests')
+        unless $self->disable_tab_tests;
+
     $self->add_plugins('PodCoverageTests')
         unless $self->disable_pod_coverage_tests;
 
